@@ -13,7 +13,7 @@ use uv_distribution_types::{
     ExtraBuildVariables, InstalledDirectUrlDist, InstalledDist, InstalledDistKind,
     PackageConfigSettings, RequirementSource,
 };
-use uv_git_types::GitOid;
+use uv_git_types::{GitLfs, GitOid};
 use uv_normalize::PackageName;
 use uv_platform_tags::{IncompatibleTag, TagCompatibility, Tags};
 use uv_pypi_types::{DirInfo, DirectUrl, VcsInfo, VcsKind};
@@ -173,6 +173,7 @@ impl RequirementSatisfaction {
                             vcs: VcsKind::Git,
                             requested_revision: _,
                             commit_id: installed_precise,
+                            git_lfs: installed_git_lfs,
                         },
                     subdirectory: installed_subdirectory,
                 } = direct_url.as_ref()
@@ -188,6 +189,16 @@ impl RequirementSatisfaction {
                     return Self::Mismatch;
                 }
 
+                let requested_git_lfs = requested_git.lfs();
+                let installed_git_lfs = installed_git_lfs.map(GitLfs::from).unwrap_or_default();
+                if requested_git_lfs != installed_git_lfs {
+                    debug!(
+                        "Git LFS mismatch: {} (installed) vs. {} (requested)",
+                        installed_git_lfs, requested_git_lfs,
+                    );
+                    return Self::Mismatch;
+                }
+
                 if !RepositoryUrl::parse(installed_url).is_ok_and(|installed_url| {
                     installed_url == RepositoryUrl::new(requested_git.repository())
                 }) {
