@@ -1441,7 +1441,7 @@ mod tests {
     async fn upload_request_source_dist() {
         let group = {
             let raw_filename = "tqdm-999.0.0.tar.gz";
-            let file = PathBuf::from("../../scripts/links/").join(raw_filename);
+            let file = PathBuf::from("../../test/links/").join(raw_filename);
             let filename = DistFilename::try_from_normalized_filename(raw_filename).unwrap();
 
             UploadDistribution {
@@ -1563,7 +1563,7 @@ mod tests {
     async fn upload_request_wheel() {
         let group = {
             let raw_filename = "tqdm-4.66.1-py3-none-manylinux_2_12_x86_64.manylinux2010_x86_64.musllinux_1_1_x86_64.whl";
-            let file = PathBuf::from("../../scripts/links/").join(raw_filename);
+            let file = PathBuf::from("../../test/links/").join(raw_filename);
             let filename = DistFilename::try_from_normalized_filename(raw_filename).unwrap();
 
             UploadDistribution {
