@@ -53,8 +53,10 @@ pub(crate) async fn install(
     with: &[RequirementsSource],
     constraints: &[RequirementsSource],
     overrides: &[RequirementsSource],
+    excludes: &[RequirementsSource],
     build_constraints: &[RequirementsSource],
     entrypoints: &[PackageName],
+    lfs: Option<bool>,
     python: Option<String>,
     python_platform: Option<TargetTriple>,
     install_mirrors: PythonInstallMirrors,
@@ -147,6 +149,7 @@ pub(crate) async fn install(
                 &workspace_cache,
                 printer,
                 preview,
+                lfs,
             )
             .await?
             .pop()
@@ -251,6 +254,7 @@ pub(crate) async fn install(
         with,
         constraints,
         overrides,
+        excludes,
         None,
         &client_builder,
     )
@@ -272,6 +276,7 @@ pub(crate) async fn install(
                 &workspace_cache,
                 printer,
                 preview,
+                lfs,
             )
             .await?,
         );
@@ -297,6 +302,7 @@ pub(crate) async fn install(
         &workspace_cache,
         printer,
         preview,
+        lfs,
     )
     .await?;
 
@@ -335,7 +341,10 @@ pub(crate) async fn install(
                             package_name.cyan()
                         );
                     }
-                    Err(uv_tool::Error::Io(err)) if err.kind() == std::io::ErrorKind::NotFound => {}
+                    Err(err)
+                        if err
+                            .as_io_error()
+                            .is_some_and(|err| err.kind() == std::io::ErrorKind::NotFound) => {}
                     Err(err) => {
                         return Err(err.into());
                     }
@@ -348,11 +357,11 @@ pub(crate) async fn install(
         installed_tools
             .get_environment(package_name, &cache)?
             .filter(|environment| {
-                if environment.uses(&interpreter) {
+                if environment.environment().uses(&interpreter) {
                     trace!(
                         "Existing interpreter matches the requested interpreter for `{}`: {}",
                         package_name,
-                        environment.interpreter().sys_executable().display()
+                        environment.environment().interpreter().sys_executable().display()
                     );
                     true
                 } else {
@@ -399,7 +408,7 @@ pub(crate) async fn install(
                 let tags = resolution_tags(None, python_platform.as_ref(), &interpreter)?;
 
                 // Check if the installed packages meet the requirements.
-                let site_packages = SitePackages::from_environment(environment)?;
+                let site_packages = SitePackages::from_environment(environment.environment())?;
                 if matches!(
                     site_packages.satisfies_requirements(
                         requirements.iter(),
@@ -461,7 +470,7 @@ pub(crate) async fn install(
     // be invalidated by moving the environment.
     let environment = if let Some(environment) = existing_environment {
         let environment = match update_environment(
-            environment,
+            environment.into_environment(),
             spec,
             Modifications::Exact,
             python_platform.as_ref(),
